==> bot-0.14.0.tar.gz: example/bot_io/completion/hello-completion.sh <==
###-begin-hello.dart-completion-###
#
# hello.dart command completion script
#
# Installation:
# 
# Via shell config file  ~/.bashrc  (or ~/.zshrc)
#
#   Append the contents to config file
#   'source' the file in the config file
#
# You may also have a directory on your system that is configured
#    for completion files, such as:
#
#    /usr/local/etc/bash_completion.d/
#

COMP_WORDBREAKS=${COMP_WORDBREAKS/=/}
COMP_WORDBREAKS=${COMP_WORDBREAKS/@/}
export COMP_WORDBREAKS

if type complete &>/dev/null; then
  _hello_dart_completion () {
    local si="$IFS"
    IFS=$'\n' COMPREPLY=($(COMP_CWORD="$COMP_CWORD" \
                           COMP_LINE="$COMP_LINE" \
                           COMP_POINT="$COMP_POINT" \
                           hello.dart completion -- "${COMP_WORDS[@]}" \
                           2>/dev/null)) || return $?
    IFS="$si"
  }
  complete -F _hello_dart_completion hello.dart
elif type compdef &>/dev/null; then
  _hello_dart_completion() {
    si=$IFS
    compadd -- $(COMP_CWORD=$((CURRENT-1)) \
                 COMP_LINE=$BUFFER \
                 COMP_POINT=0 \
                 hello.dart completion -- "${words[@]}" \
                 2>/dev/null)
    IFS=$si
  }
  compdef _hello_dart_completion hello.dart
elif type compctl &>/dev/null; then
  _hello_dart_completion () {
    local cword line point words si
    read -Ac words
    read -cn cword
    let cword-=1
    read -l line
    read -ln point
    si="$IFS"
    IFS=$'\n' reply=($(COMP_CWORD="$cword" \
                       COMP_LINE="$line" \
                       COMP_POINT="$point" \
                       hello.dart completion -- "${words[@]}" \
                       2>/dev/null)) || return $?
    IFS="$si"
  }
  compctl -K _hello_dart_completion hello.dart
fi

## Generated on 2013-02-14 17:35:48.805
###-end-hello.dart-completion-###

==> bot-0.14.1.tar.gz: example/bot_io/completion/hello-completion.sh <==
###-begin-hello.dart-completion-###
#
# Command completion script: "hello.dart"
#
# Installation:
# 
# Via shell config file  ~/.bashrc  (or ~/.zshrc)
#
#   Append the contents to config file
#   'source' the file in the config file
#
# You may also have a directory on your system that is configured
#    for completion files, such as:
#
#    /usr/local/etc/bash_completion.d/
#

if type complete &>/dev/null; then
  __hello_dart_completion() {
    local si="$IFS"
    IFS=$'\n' COMPREPLY=($(COMP_CWORD="$COMP_CWORD" \
                           COMP_LINE="$COMP_LINE" \
                           COMP_POINT="$COMP_POINT" \
                           hello.dart completion -- "${COMP_WORDS[@]}" \
                           2>/dev/null)) || return $?
    IFS="$si"
  }
  complete -F __hello_dart_completion hello.dart
elif type compdef &>/dev/null; then
  __hello_dart_completion() {
    si=$IFS
    compadd -- $(COMP_CWORD=$((CURRENT-1)) \
                 COMP_LINE=$BUFFER \
                 COMP_POINT=0 \
                 hello.dart completion -- "${words[@]}" \
                 2>/dev/null)
    IFS=$si
  }
  compdef __hello_dart_completion hello.dart
elif type compctl &>/dev/null; then
  __hello_dart_completion() {
    local cword line point words si
    read -Ac words
    read -cn cword
    let cword-=1
    read -l line
    read -ln point
    si="$IFS"
    IFS=$'\n' reply=($(COMP_CWORD="$cword" \
                       COMP_LINE="$line" \
                       COMP_POINT="$point" \
                       hello.dart completion -- "${words[@]}" \
                       2>/dev/null)) || return $?
    IFS="$si"
  }
  compctl -K __hello_dart_completion hello.dart
fi

## Generated 2013-02-23 18:12:41.235Z
## By /Users/kevin/source/github/bot.dart/bin/shell_completion_generator.dart
###-end-hello.dart-completion-###
